@@ -1,4 +1,4 @@
-# $Id: emoncms.py 971 2014-07-28 23:16:44Z mwall $
+# $Id: emoncms.py 1033 2014-09-05 02:51:38Z mwall $
 # Copyright 2013 Matthew Wall
 
 # Upload data to EmonCMS
@@ -172,14 +172,20 @@ class EmonCMSThread(weewx.restx.RESTThread):
         data = []
         if self.input_map is not None:
             for k in self.input_map:
-                v = record.get(k)
-                if v is not None:
+                try:
+                    v = float(record.get(k))
                     s = self.input_map[k] % v
                     data.append('%s%s' % (prefix, s))
+                except ValueError:
+                    pass
         else:
             for k in record:
-                s = '%s:%s' % (k, record[k])
-                data.append('%s%s' % (prefix, s))
+                try:
+                    v = float(record[k])
+                    s = '%s:%s' % (k, v)
+                    data.append('%s%s' % (prefix, s))
+                except ValueError:
+                    pass
         # assemble the complete url from all the variables and values
         url = '%s?apikey=%s&time=%s&json={%s}' % (
             self.server_url, self.token, record['dateTime'], ','.join(data))
